"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const migration_1 = require("./migration");
const git_1 = require("./git");
const url_1 = require("url");
class InvalidConnectionError extends Error {
    constructor(url) {
        super('Invalid connection URL ' + url);
    }
}
exports.InvalidConnectionError = InvalidConnectionError;
class UnsupportedDialectError extends Error {
    constructor(dialect) {
        super('Unsupported dialect: ' + dialect);
    }
}
exports.UnsupportedDialectError = UnsupportedDialectError;
class DbAdapter {
    rowToTask(row) {
        const task = new migration_1.Task({
            id: row['id'],
            type: row['type'],
            appliedAt: row['applied_at'],
            commit: new git_1.Commit({
                sha1: row['commit']
            }),
            head: new git_1.Commit({
                sha1: row['head']
            }),
            migration: new migration_1.Migration({
                name: row['name']
            })
        });
        return task;
    }
}
exports.DbAdapter = DbAdapter;
const postgres_1 = require("./adapters/postgres");
function createAdapterFromUrl(url) {
    const dialect = url_1.parse(url).protocol;
    switch (dialect) {
        case 'postgres:':
            try {
                return new postgres_1.PostgresAdapter(url, require(process.cwd() + '/node_modules/pg'));
            }
            catch (err) {
                /* istanbul ignore next */
                return new postgres_1.PostgresAdapter(url, require('pg'));
            }
        case null: throw new InvalidConnectionError(url);
        default: throw new UnsupportedDialectError(dialect);
    }
}
exports.createAdapterFromUrl = createAdapterFromUrl;
//# sourceMappingURL=adapter.js.map