"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const adapter_1 = require("../adapter");
const assert = require("assert");
const postgres_1 = require("../adapters/postgres");
describe('Adapter', () => {
    describe('createAdapterFromUrl', () => {
        it('should return a postgres adapter for a postgres url', () => __awaiter(this, void 0, void 0, function* () {
            const adapter = adapter_1.createAdapterFromUrl('postgres://postgres@localhost/db');
            assert(adapter instanceof postgres_1.PostgresAdapter, 'adapter is no postgres adapter');
        }));
        it('should throw for invalid connection urls', () => __awaiter(this, void 0, void 0, function* () {
            try {
                adapter_1.createAdapterFromUrl('');
                throw new assert.AssertionError({
                    message: 'it did not throw for an invalid connection url'
                });
            }
            catch (err) {
                if (!(err instanceof adapter_1.InvalidConnectionError)) {
                    throw err;
                }
            }
        }));
        it('should throw for unsupported db dialects', () => __awaiter(this, void 0, void 0, function* () {
            try {
                adapter_1.createAdapterFromUrl('mysql://user@localhost/test');
                throw new assert.AssertionError({
                    message: 'it did not throw for an unsupported db dialect'
                });
            }
            catch (err) {
                if (!(err instanceof adapter_1.UnsupportedDialectError)) {
                    throw err;
                }
            }
        }));
    });
});
//# sourceMappingURL=adapter.test.js.map