"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const child_process_1 = require("mz/child_process");
const index_1 = require("../index");
const adapter_1 = require("../adapter");
const git_1 = require("../git");
const fs = require("mz/fs");
const assert = require("assert");
const assert_1 = require("assert");
const pg = require("pg");
const del = require("del");
const path = require("path");
const PATH = path.resolve(__dirname + '/../../bin') + path.delimiter + process.env.PATH;
describe('E2E', () => {
    let client;
    const repo = os_1.tmpdir() + '/merkel_test_repo';
    before(function () {
        return __awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            client = new pg.Client(process.env.MERKEL_DB);
            yield new Promise((resolve, reject) => client.connect((err) => err ? reject(err) : resolve()));
            yield client.query('DROP TABLE IF EXISTS "new_table"');
            yield client.query('DROP TABLE IF EXISTS merkel_meta');
            try {
                yield fs.access(repo);
            }
            catch (err) {
                yield fs.mkdir(repo);
            }
            process.chdir(repo);
            yield del('*', { dot: true });
            yield child_process_1.exec('npm i pg');
        });
    });
    it('should behave properly', function () {
        return __awaiter(this, void 0, void 0, function* () {
            this.timeout(10000);
            const adapter = adapter_1.createAdapterFromUrl(process.env.MERKEL_DB);
            yield adapter.init();
            yield child_process_1.execFile('git', ['init']);
            yield index_1.createMigrationDir('migrations');
            yield index_1.createConfig({
                migrationDir: 'migrations',
                migrationOutDir: 'migrations'
            });
            yield git_1.addGitHook();
            let uuid = yield index_1.generate({ migrationDir: 'migrations' }, index_1.SILENT_LOGGER);
            let file = `migrations/${uuid}.js`;
            yield fs.access(file).catch(() => new assert_1.AssertionError({ message: 'migration file not created' }));
            yield fs.writeFile('User.ts', 'class User {}');
            yield fs.writeFile(file, yield fs.readFile(__dirname + '/migrations/test_migration.js'));
            yield child_process_1.execFile('git', ['config', 'user.email', 'whatever@whatever.com']);
            yield child_process_1.execFile('git', ['config', 'user.name', 'whatever']);
            yield child_process_1.execFile('git', ['add', file, 'User.ts', '.merkelrc.json']);
            yield child_process_1.execFile('git', ['commit', '-m', `first migration\n\n[merkel up ${uuid}]`], { env: { PATH } });
            let status = yield index_1.getStatus(adapter, yield git_1.getHead());
            assert.equal(status.newCommits.length, 1);
            yield status.executePendingTasks('migrations', adapter, index_1.SILENT_LOGGER);
            const { rows } = yield client.query(`SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE table_name = 'new_table'`);
            assert.equal(rows.length, 1);
            yield child_process_1.execFile('git', ['revert', '--no-commit', 'HEAD']);
            yield child_process_1.execFile('git', ['reset', 'HEAD', 'migrations']);
            yield child_process_1.execFile('git', ['checkout', '--', 'migrations']);
            yield child_process_1.execFile('git', ['commit', '-m', `Revert of User\n\n[merkel down ${uuid}]`], { env: { PATH } });
            const downStatus = yield index_1.getStatus(adapter, yield git_1.getHead());
            assert.equal(downStatus.newCommits.length, 1);
            yield downStatus.executePendingTasks('migrations', adapter, index_1.SILENT_LOGGER);
            let response = yield client.query(`SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE table_name = 'new_table'`);
            assert.equal(response.rows.length, 0);
            yield index_1.createConfig({
                migrationDir: 'src/migrations',
                migrationOutDir: 'src/migrations'
            });
            uuid = yield index_1.generate({ migrationDir: 'src/migrations' }, index_1.SILENT_LOGGER);
            file = `src/migrations/${uuid}.js`;
            yield fs.access(file).catch(() => new assert_1.AssertionError({ message: 'migration file not created' }));
            yield fs.writeFile(file, yield fs.readFile(__dirname + '/migrations/test_migration.js'));
            yield child_process_1.execFile('git', ['add', file, '.merkelrc.json']);
            yield child_process_1.execFile('git', ['commit', '-m', `migration in a new folder\n\n[merkel up ${uuid}]`], { env: { PATH } });
            status = yield index_1.getStatus(adapter, yield git_1.getHead());
            assert.equal(status.newCommits.length, 1);
            yield status.executePendingTasks('migrations', adapter, index_1.SILENT_LOGGER);
            response = yield client.query(`SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE table_name = 'new_table'`);
            assert.equal(response.rows.length, 1);
        });
    });
    after(() => __awaiter(this, void 0, void 0, function* () { return yield client.end(); }));
});
//# sourceMappingURL=e2e.test.js.map